/****************************************************************
* FILENAME: trf796xBoosterPack.c
*
* BRIEF: Contains MSP430G2553 specific functions.
*
* Copyright (C) 2010 Texas Instruments, Inc.
*
* AUTHOR(S): Reiser Peter        DATE: 02 DEC 2010
*
* EDITED BY:
* *
*
****************************************************************/

#include "trf796xBoosterPack.h"

//===============================================================


//===============================================================
// NAME: void McuDelayMillisecond (u08_t n_ms)
//
// BRIEF: Is used to create delays.
//
// INPUTS:
//    Parameters:
//        u08_t        n_ms        delay time in ms
//
// OUTPUTS:
//
// PROCESS:    [1] do loop of 1 ms duration as often as required
//
// CHANGE:
// DATE          WHO    DETAIL
// 23Nov2010    RP    Original Code
//===============================================================

void
McuDelayMillisecond(u32_t n_ms)
{
    while (n_ms--)
    {
        __delay_cycles(DELAY_1ms);        // clock speed in Hz divided by 1000
    }
}

//===============================================================
// NAME: void McuCounterSet (void)
//
// BRIEF: Is used to set the timerA.
//
// INPUTS:
//
// OUTPUTS:
//
// PROCESS:    [1] set timerA
//
// CHANGE:
// DATE          WHO    DETAIL
// 23Nov2010    RP    Original Code
//===============================================================

void
McuCounterSet(void)
{
    TACTL |= TASSEL_1 + TACLR;      // ACLK, timer stoped

    TACCTL0 |= CCIE;                // compare interrupt enable
}

//===============================================================
// NAME: void McuOscSel (u08_t mode)
//
// BRIEF: Is used to select the oscilator.
//
// INPUTS:
//    Parameters:
//        u08_t        mode        crystal oscillator or DCO for
//                        main clock
//
// OUTPUTS:
//
// PROCESS:    [1] select the oscillator
//
// CHANGE:
// DATE          WHO    DETAIL
// 23Nov2010    RP    Original Code
//===============================================================

void
McuOscSel(u08_t mode)
{
    u08_t ii1 = 0;

    if (mode == 0x00)
    {
        // select crystal oscilator

        BCSCTL1 |= XTS;               // ACLK = LFXT1 HF XTAL
        BCSCTL3 |= LFXT1S1;                    // 3  16MHz crystal or resonator
        // turn external oscillator on
        do
        {
            IFG1 &= ~OFIFG;                           // Clear OSCFault flag
            for (ii1 = 0xFF; ii1 > 0; ii1--);         // Time delay for flag to set
        } while ((IFG1 & OFIFG) == OFIFG);            // OSCFault flag still set?

        BCSCTL2 |= SELM_2 + SELS;                       // MCLK = SMCLK = HF LFXT1 (safe)
    }
    else                                               //select DCO for main clock
    {
        // select DCO to 8MHz

        if (CALBC1_8MHZ != 0xFF)
        {
            // Follow recommended flow. First, clear all DCOx and MODx bits.
            // Then apply new RSELx values. Finally, apply new DCOx and MODx bit
            // values.
            DCOCTL = 0x00;
            BCSCTL1 = CALBC1_8MHZ;
            DCOCTL = CALDCO_8MHZ;
        }

        // Disable XT1 pins
        P2SEL &= ~(BIT6 + BIT7);

        // Disable XT1 high frequency mode
        BCSCTL1 &= ~XTS;

        // Set XT1 to VLO
        BCSCTL3 |= LFXT1S_2;
    }
}


